@@ -1,6 +1,6 @@
 from django.db import models, transaction
 from django.db.models.signals import post_delete
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class FormSubmissionFile(models.Model):
